[Bf-blender-cvs] [946ae26349e] master: UI: use term current frame instead of playhead

Campbell Barton noreply at git.blender.org
Mon Jun 1 07:01:52 CEST 2020


Commit: 946ae26349eedbd6d7bdd859280c10ad80520417
Author: Campbell Barton
Date:   Mon Jun 1 14:41:12 2020 +1000
Branches: master
https://developer.blender.org/rB946ae26349eedbd6d7bdd859280c10ad80520417

UI: use term current frame instead of playhead

Avoid mixing different terminologies up,
current frame is used in a majority of Blender.

===================================================================

M	release/scripts/startup/bl_operators/sequencer.py
M	release/scripts/startup/bl_ui/space_sequencer.py
M	source/blender/editors/space_action/action_edit.c
M	source/blender/editors/space_graph/graph_edit.c
M	source/blender/editors/space_nla/nla_edit.c
M	source/blender/editors/space_sequencer/sequencer_draw.c
M	source/blender/editors/space_sequencer/sequencer_edit.c
M	source/blender/editors/space_sequencer/sequencer_select.c
M	source/blender/makesrna/intern/rna_sequencer.c

===================================================================

diff --git a/release/scripts/startup/bl_operators/sequencer.py b/release/scripts/startup/bl_operators/sequencer.py
index 206f778195e..af071561232 100644
--- a/release/scripts/startup/bl_operators/sequencer.py
+++ b/release/scripts/startup/bl_operators/sequencer.py
@@ -188,7 +188,7 @@ class SequencerFadesAdd(Operator):
             ('CURSOR_TO', 'To Playhead', 'Fade from the start of sequences under the time cursor to the current frame'),
         ),
         name="Fade type",
-        description="Fade in, out, both in and out, to, or from the playhead. Default is both in and out",
+        description="Fade in, out, both in and out, to, or from the current frame. Default is both in and out",
         default='IN_OUT')
 
     @classmethod
diff --git a/release/scripts/startup/bl_ui/space_sequencer.py b/release/scripts/startup/bl_ui/space_sequencer.py
index 9c20a55c294..76523e1ab04 100644
--- a/release/scripts/startup/bl_ui/space_sequencer.py
+++ b/release/scripts/startup/bl_ui/space_sequencer.py
@@ -1585,10 +1585,10 @@ class SEQUENCER_PT_time(SequencerButtonsPanel, Panel):
         split.alignment = 'RIGHT'
         split.label(text="Playhead")
         split = split.split(factor=0.8 + max_factor, align=True)
-        playhead = frame_current - frame_final_start
-        split.label(text="{:>14}".format(smpte_from_frame(playhead)))
+        frame_display = frame_current - frame_final_start
+        split.label(text="{:>14}".format(smpte_from_frame(frame_display)))
         split.alignment = 'RIGHT'
-        split.label(text=str(playhead) + " ")
+        split.label(text=str(frame_display) + " ")
 
         if strip.type == 'SCENE':
             scene = strip.scene
diff --git a/source/blender/editors/space_action/action_edit.c b/source/blender/editors/space_action/action_edit.c
index e90122f2585..576b52a5cdd 100644
--- a/source/blender/editors/space_action/action_edit.c
+++ b/source/blender/editors/space_action/action_edit.c
@@ -490,7 +490,7 @@ void ACTION_OT_view_frame(wmOperatorType *ot)
   /* identifiers */
   ot->name = "Go to Current Frame";
   ot->idname = "ACTION_OT_view_frame";
-  ot->description = "Move the view to the playhead";
+  ot->description = "Move the view to the current frame";
 
   /* api callbacks */
   ot->exec = actkeys_view_frame_exec;
diff --git a/source/blender/editors/space_graph/graph_edit.c b/source/blender/editors/space_graph/graph_edit.c
index 8ffd2844f1a..a974ec612a9 100644
--- a/source/blender/editors/space_graph/graph_edit.c
+++ b/source/blender/editors/space_graph/graph_edit.c
@@ -385,7 +385,7 @@ void GRAPH_OT_view_frame(wmOperatorType *ot)
   /* identifiers */
   ot->name = "Go to Current Frame";
   ot->idname = "GRAPH_OT_view_frame";
-  ot->description = "Move the view to the playhead";
+  ot->description = "Move the view to the current frame";
 
   /* api callbacks */
   ot->exec = graphkeys_view_frame_exec;
diff --git a/source/blender/editors/space_nla/nla_edit.c b/source/blender/editors/space_nla/nla_edit.c
index f68896e21d6..dec7a0fd93c 100644
--- a/source/blender/editors/space_nla/nla_edit.c
+++ b/source/blender/editors/space_nla/nla_edit.c
@@ -567,7 +567,7 @@ void NLA_OT_view_frame(wmOperatorType *ot)
   /* identifiers */
   ot->name = "Go to Current Frame";
   ot->idname = "NLA_OT_view_frame";
-  ot->description = "Move the view to the playhead";
+  ot->description = "Move the view to the current frame";
 
   /* api callbacks */
   ot->exec = nlaedit_viewframe_exec;
diff --git a/source/blender/editors/space_sequencer/sequencer_draw.c b/source/blender/editors/space_sequencer/sequencer_draw.c
index 5d8851d5e3d..1f06ab68516 100644
--- a/source/blender/editors/space_sequencer/sequencer_draw.c
+++ b/source/blender/editors/space_sequencer/sequencer_draw.c
@@ -2299,10 +2299,10 @@ void draw_timeline_seq(const bContext *C, ARegion *region)
     cfra_flag |= DRAWCFRA_UNIT_SECONDS;
   }
 
-  /* Draw playhead. */
+  /* Draw the current frame indicator. */
   ANIM_draw_cfra(C, v2d, cfra_flag);
 
-  /* Draw overlap playhead. */
+  /* Draw overlap frame frame indicator. */
   if (scene->ed && scene->ed->over_flag & SEQ_EDIT_OVERLAY_SHOW) {
     int cfra_over = (scene->ed->over_flag & SEQ_EDIT_OVERLAY_ABS) ?
                         scene->ed->over_cfra :
diff --git a/source/blender/makesrna/intern/rna_sequencer.c b/source/blender/makesrna/intern/rna_sequencer.c
index 45d7bc24017..39ea054456f 100644
--- a/source/blender/makesrna/intern/rna_sequencer.c
+++ b/source/blender/makesrna/intern/rna_sequencer.c
@@ -2016,7 +2016,7 @@ static void rna_def_editor(BlenderRNA *brna)
   RNA_def_property_ui_text(
       prop,
       "Prefetch Frames",
-      "Render frames ahead of playhead in the background for faster playback");
+      "Render frames ahead of current frame in the background for faster playback");
   RNA_def_property_update(prop, NC_SCENE | ND_SEQUENCER, NULL);
 
   prop = RNA_def_property(srna, "recycle_max_cost", PROP_FLOAT, PROP_NONE);



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/editors/space_sequencer/sequencer_edit.c b/source/blender/editors/space_sequencer/sequencer_edit.c
index 7898c7fa8d0..ea0d5785d22 100644
--- a/source/blender/editors/space_sequencer/sequencer_edit.c
+++ b/source/blender/editors/space_sequencer/sequencer_edit.c
@@ -311,7 +311,7 @@ static int mouse_frame_side(View2D *v2d, short mouse_x, int frame)
   mval[0] = mouse_x;
   mval[1] = 0;
 
   /* Choose the side based on which side of the playhead the mouse is on. */
   UI_view2d_region_to_view(v2d, mval[0], mval[1], &mouseloc[0], &mouseloc[1]);
 
   return mouseloc[0] > frame ? SEQ_SIDE_RIGHT : SEQ_SIDE_LEFT;
@@ -1376,7 +1376,7 @@ static int sequencer_snap_invoke(bContext *C, wmOperator *op, const wmEvent *UNU
 void SEQUENCER_OT_snap(struct wmOperatorType *ot)
 {
   /* Identifiers. */
-  ot->name = "Snap Strips to Playhead";
+  ot->name = "Snap Strips to the Current Frame";
   ot->idname = "SEQUENCER_OT_snap";
   ot->description = "Frame where selected strips will be snapped";
 
@@ -1727,7 +1727,7 @@ static int sequencer_slip_modal(bContext *C, wmOperator *op, const wmEvent *even
           mouse_x = event->mval[0];
         }
 
         /* Choose the side based on which side of the playhead the mouse is. */
         UI_view2d_region_to_view(v2d, mouse_x, 0, &mouseloc[0], &mouseloc[1]);
         offset = mouseloc[0] - data->init_mouseloc[0];
 
@@ -2374,7 +2374,7 @@ void SEQUENCER_OT_split(struct wmOperatorType *ot)
                   "use_cursor_position",
                   0,
                   "Use Cursor Position",
-                  "Split at position of the cursor instead of playhead");
+                  "Split at position of the cursor instead of current frame");
 
   prop = RNA_def_enum(ot->srna,
                       "side",
@@ -2976,7 +2976,7 @@ void SEQUENCER_OT_view_frame(wmOperatorType *ot)
   /* Identifiers. */
   ot->name = "Go to Current Frame";
   ot->idname = "SEQUENCER_OT_view_frame";
-  ot->description = "Move the view to the playhead";
+  ot->description = "Move the view to the current frame";
 
   /* Api callbacks. */
   ot->exec = sequencer_view_frame_exec;
@@ -311,7 +311,7 @@ static int mouse_frame_side(View2D *v2d, short mouse_x, int frame)
   mval[1] = 0;
 
-  /* Choose the side based on which side of the playhead the mouse is on. */
+  /* Choose the side based on which side of the current frame the mouse is on. */
   UI_view2d_region_to_view(v2d, mval[0], mval[1], &mouseloc[0], &mouseloc[1]);
 
@@ -1727,7 +1727,7 @@ static int sequencer_slip_modal(bContext *C, wmOperator *op, const wmEvent *even
         }
 
-        /* Choose the side based on which side of the playhead the mouse is. */
+        /* Choose the side based on which side of the current frame the mouse is. */
         UI_view2d_region_to_view(v2d, mouse_x, 0, &mouseloc[0], &mouseloc[1]);
         offset = mouseloc[0] - data->init_mouseloc[0];
diff --git a/source/blender/editors/space_sequencer/sequencer_select.c b/source/blender/editors/space_sequencer/sequencer_select.c
index a8779d96248..25e1b70482e 100644
--- a/source/blender/editors/space_sequencer/sequencer_select.c
+++ b/source/blender/editors/space_sequencer/sequencer_select.c
@@ -412,7 +412,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
 
     ret_value = OPERATOR_FINISHED;
   }
   /* Select left, right or under playhead. */
   else if (left_right != SEQ_SELECT_LR_NONE) {
     /* Use different logic for this. */
     float x;
@@ -422,7 +422,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
 
     switch (left_right) {
       case SEQ_SELECT_LR_MOUSE: {
         /* 10px margin around playhead to select under playhead with mouse. */
         float margin = BLI_rctf_size_x(&v2d->cur) / BLI_rcti_size_x(&v2d->mask) * 10;
         x = UI_view2d_region_to_view_x(v2d, mval[0]);
         if (x >= CFRA - margin && x <= CFRA + margin) {
@@ -443,7 +443,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
     }
 
     SEQP_BEGIN (ed, seq) {
-      /* Select under playhead. */
+      /* Select overlapping the current frame. */
       if ((x == CFRA) && (seq->startdisp <= CFRA) && (seq->enddisp >= CFRA)) {
         seq->flag = SELECT;
         recurs_sel_seq(seq);
@@ -643,9 +643,9 @@ void SEQUENCER_OT_select(wmOperatorType *ot)
   static const EnumPropertyItem sequencer_select_left_right_types[] = {
       {SEQ_SELECT_LR_NONE, "NONE", 0, "None", "Don't do left-right selection"},
       {SEQ_SELECT_LR_MOUSE, "MOUSE", 0, "Mouse", "Use mouse position for selection"},
-      {SEQ_SELECT_LR_LEFT, "LEFT", 0, "Left", "Select to the left of the playhead"},
-      {SEQ_SELECT_LR_RIGHT, "RIGHT", 0, "Right", "Select to the right of the playhead"},
-      {SEQ_SELECT_LR_UNDER_PLAYHEAD, "UNDER", 0, "Under", "Select under the playhead"},
+      {SEQ_SELECT_LR_LEFT, "LEFT", 0, "Left", "Select to the left of the current frame"},
+      {SEQ_SELECT_LR_RIGHT, "RIGHT", 0, "Right", "Select to the right of the current frame"},
+      {SEQ_SELECT_LR_UNDER_PLAYHEAD, "UNDER", 0, "Under", "Select under the current frame"},
       {0, NULL, 0, NULL, NULL},
   };
   PropertyRNA *prop;
@@ -412,7 +412,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
     ret_value = OPERATOR_FINISHED;
   }
-  /* Select left, right or under playhead. */
+  /* Select left, right or overlapping the current frame. */
   else if (left_right != SEQ_SELECT_LR_NONE) {
     /* Use different logic for this. */
@@ -422,7 +422,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
     switch (left_right) {
       case SEQ_SELECT_LR_MOUSE: {
-        /* 10px margin around playhead to select under playhead with mouse. */
+        /* 10px margin around current frame to select under the current frame with mouse. */
         float margin = BLI_rctf_size_x(&v2d->cur) / BLI_rcti_size_x(&v2d->mask) * 10;
         x = UI_view2d_region_to_view_x(v2d, mval[0]);